@@ -24,9 +24,9 @@
 #include <new>
 
 #include <QApplication>
+#include <QElapsedTimer>
 #include <QProgressDialog>
 #include <QThread>
-#include <QTime>
 #include <QVariantList>
 #include <QWidget>
 
@@ -330,6 +330,7 @@ void Kwave::Plugin::closeProgressDialog(Kwave::Plugin *)
 void Kwave::Plugin::cancel()
 {
     m_stop = true;
+    if (m_thread) m_thread->requestInterruption();
 }
 
 //***************************************************************************
@@ -358,6 +359,12 @@ bool Kwave::Plugin::canClose() const
     return !isRunning();
 }
 
+//***************************************************************************
+bool Kwave::Plugin::shouldStop() const
+{
+    return (m_stop || (m_thread && m_thread->isInterruptionRequested()));
+}
+
 //***************************************************************************
 bool Kwave::Plugin::isRunning() const
 {
@@ -377,7 +384,7 @@ void Kwave::Plugin::run_wrapper(const QVariant &params)
     emit sigRunning(this);
 
     // start time measurement
-    QTime t;
+    QElapsedTimer t;
     t.start();
 
     // call the plugin's run function in this worker thread context
